from Deadline.Events import *
from Deadline.Scripting import *

######################################################################
## This is the function that Deadline calls to get an instance of the
## main DeadlineEventListener class.
######################################################################
def GetDeadlineEventListener():
    return ReQueueMe()

######################################################################
## This is the function that Deadline calls when the event plugin is
## no longer in use so that it can get cleaned up.
######################################################################
def CleanupDeadlineEventListener( deadlinePlugin ):
    deadlinePlugin.Cleanup()

######################################################################
## This is the main DeadlineEventListener class for ReQueueMe.
######################################################################
class ReQueueMe (DeadlineEventListener):

    def __init__(self):
        # Set up the event callbacks here
        self.OnJobErrorCallback += self.OnJobError
		
    def Cleanup(self):
        del self.OnJobErrorCallback		
        
    def OnJobError(self, job, task, errorReport):
        # TODO: Connect to pipeline site to notify it that a job has been submitted
        # for a particular shot or task.
        new_TimeOut = self.GetConfigEntry("NewTimeout")
        new_Priority = self.GetConfigEntry("NewPriority")
        new_Pool = self.GetConfigEntry("Pool")
        self.LogInfo( "Hi! This task has reached the 4h render limit." )
        #self.LogInfo(errorReport)
        self.LogInfo( "It has been automatically requeued without time limit, but with a lower priority (12)." )
        job.JobTaskTimeoutSeconds = new_TimeOut * 60
        job.JobPriority = new_Priority 
        job.JobPool = new_Pool
        #self.LogInfo(errorReport)
        #self.LogInfo("test Alo")
        RepositoryUtils.SaveJob(job)